server

package
v0.7.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 1, 2023 License: MIT Imports: 21 Imported by: 0

Documentation

Overview

Package server configures and starts the Valkyrie server as well as middlewares

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Valkyrie

type Valkyrie struct {
	// contains filtered or unexported fields
}

Valkyrie struct containing information and configuration on configured providers and operator

func NewValkyrie

func NewValkyrie(ctx context.Context, cfg *configs.ValkyrieConfig) *Valkyrie

NewValkyrie use provided cfg to create a Valkyrie instance

func (*Valkyrie) Run

func (v *Valkyrie) Run(ready func())

Run starts the server and hangs until it's context gets cancelled. The `ready` callback gets fired when the server is ready for accepting connections.

func (*Valkyrie) Start

func (v *Valkyrie) Start()

Run Starts provider and operator servers. Returns only when listeners are ready.

func (*Valkyrie) Stop

func (v *Valkyrie) Stop()

Stop stops provider and operator servers

Jump to