Documentation
¶
Overview ¶
Package server configures and starts the Valkyrie server as well as middlewares
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Valkyrie ¶
type Valkyrie struct {
// contains filtered or unexported fields
}
Valkyrie struct containing information and configuration on configured providers and operator
func NewValkyrie ¶
func NewValkyrie(ctx context.Context, cfg *configs.ValkyrieConfig) *Valkyrie
NewValkyrie use provided cfg to create a Valkyrie instance
func (*Valkyrie) Run ¶
func (v *Valkyrie) Run(ready func())
Run starts the server and hangs until it's context gets cancelled. The `ready` callback gets fired when the server is ready for accepting connections.
Click to show internal directories.
Click to hide internal directories.